@@ -4,27 +4,28 @@ use strict ;
 use warnings ;
 
 use Spreadsheet::Perl ;
-use Spreadsheet::Perl::QuerySet ;
-use Spreadsheet::Perl::Devel ;
-use Spreadsheet::Perl::RangeValues ;
 
 tie my %ss, "Spreadsheet::Perl" ;
 my $ss = tied %ss ;
 
-$ss{'A1:A5'} = Spreadsheet::Perl::RangeValues(reverse 1 .. 10) ;
+$ss{'A1:A5'} = RangeValues(reverse 1 .. 10) ;
 print $ss->Dump(['A1:A5']) ;
 
-$ss{'A1:A5'} = Spreadsheet::Perl::RangeValuesSub(\&Filler, [11, 22, 33]) ;
+$ss{'A1:A5'} = RangeValuesSub(\&Filler, [11, 22, 33]) ;
 print $ss->Dump(['A1:A5'], 0) ;
 
-@ss{'A1', 'B1:C2', 'A8'} = ('A', Spreadsheet::Perl::RangeValues(reverse 1 .. 10), -1) ;
+@ss{'A1', 'B1:C2', 'A8'} = ('A', RangeValues(reverse 1 .. 10), -1) ;
 print $ss->Dump() ;
 
 @ss{'A1', 'B1:C2', 'A8'} = ('A', 'B', 'C');
 print $ss->Dump() ;
 
+@ss{'A1:A5'} = 'data' x 10 ;
+print $ss->Dump(undef, 0, {DISPLAY_PERL_SIZE => 1}) ;
+
+#~ print $ss->Dump(undef, 0, {DISPLAY_PERL_SIZE => 1, DISPLAY_PERL_ADDRESS => 10}) ;
 #~ use Devel::Size::Report qw/report_size/;
-#~ print report_size($ss, { indend => "    " } );
+#~ print report_size($ss->{CELLS}, { indend => "    " } );
 
 
 #-------------------------------------------------------------
