@@ -1,4 +1,14 @@
 
+sub AddOne
+{
+my $ss = shift ;
+my $address = shift ;
+
+return($ss->Get($address) + 1) ;
+}
+
+DefineSpreadsheetFunction('AddOne', \&AddOne) ;
+
 sub OneMillion
 {
 return(1_000_000) ;
@@ -9,11 +19,11 @@ return(1_000_000) ;
 #-----------------------------------------------------------------
 
 A1 => 120, 
-A2 => sub{1},
-A3 => Formula('$ss->Sum("A1:A2")'),
+A3 => PerlFormula('$ss->AddOne("A1") + $ss->Sum("A1:A2")'),
+A4 => sub{1},
 
 B1 => 3,
 
 c2 => "hi there",
 
-D1 => OneMillion()
\ No newline at end of file
+D1 => OneMillion()
